View source: R/create_package.R
| create_package | R Documentation |
Initiates a Data Package object, either from scratch or from an existing list. This Data Package object is a list with the following characteristics:
A datapackage subclass.
All properties of the original descriptor.
A resources property, set to an empty list if undefined.
A directory property, set to "." for the current directory if
undefined.
It is used as the base path to access resources with read_resource().
create_package(descriptor = NULL)
descriptor |
List to be made into a Data Package object. If undefined, an empty Data Package will be created from scratch. |
See vignette("data-package") to learn how this function implements the
Data Package standard.
check_package() is automatically called on the created package to make sure
it is valid.
A Data Package object.
Other create functions:
create_schema()
# Create a Data Package
package <- create_package()
package
# See the structure of the (empty) Data Package
str(package)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.