| version | R Documentation |
Determines what version of the Data Package standard is used by a Data Package, based on the
$schema
property.
Version "1.0" is assumed if $schema is missing, version ">=2.0" is
assumed for custom values (e.g. extensions).
version(package)
package |
Data Package object, as returned by |
Data Package version number (e.g. "1.0").
package <- example_package()
version(package)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.